@@ -12,7 +12,7 @@ qx.Class.define("callbackery.ui.plugin.Form", {
     extend : qx.ui.container.Composite,
     /**
      * create a page for the View Tab with the given title
-     * 
+     *
      * @param vizWidget {Widget} visualization widget to embedd
      */
     construct : function(cfg,getParentFormData) {
@@ -54,7 +54,7 @@ qx.Class.define("callbackery.ui.plugin.Form", {
         },this);
     },
     events: {
-        actionResponse: 'qx.event.type.Data' 
+        actionResponse: 'qx.event.type.Data'
     },
     members: {
         _form: null,
@@ -143,9 +143,10 @@ qx.Class.define("callbackery.ui.plugin.Form", {
             // this.setEnabled(false);
             var that = this;
             var rpc = callbackery.data.Server.getInstance();
-            if (this._loading++ > 0){
+            if (this._loading > 0){
                 return;
             }
+            this._loading++;
             var parentFormData = {};
             if (this._getParentFormData){
                 parentFormData = this._getParentFormData();
